#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-5oT0Wocuz7gRbXJUwq9cc
key:                  data-checked-0.3-5oT0Wocuz7gRbXJUwq9cc
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties 
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  71434a3b3bf1e61e49e8744ee1d690c0
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-checked-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-checked
hs-libraries:         HSdata-checked-0.3-5oT0Wocuz7gRbXJUwq9cc
depends:              base-4.18.2.1 deepseq-1.4.8.1
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

